@@ -32,7 +32,7 @@ resizer.run = function(){
         $("body").addClass(mode);
         resizer.onResize();
     }
-    resizer.refreshDebugDiv();
+    //resizer.refreshDebugDiv();
 };
 
 resizer.onResize = function ()
@@ -55,7 +55,7 @@ resizer.refreshDebugDiv = function ()
     {
         $("body").append('<div id="debug"></div>');
         //$("#debug").css({'position':'fixed', 'right':'0', 'top':'0', 'background-color':'#000', 'color':'#fff', 'width':'50px', 'height':'20px', 'font-size':'11px'}).text(width)
-        $("#debug").css({'position':'fixed', 'right':'0', 'top':'0', 'background-color':'#000', 'color':'#fff', 'width':'50px', 'height':'20px', 'font-size':'11px'}).text(resizer.currentMode)
+        //$("#debug").css({'position':'fixed', 'right':'0', 'top':'0', 'background-color':'#000', 'color':'#fff', 'width':'50px', 'height':'20px', 'font-size':'11px'}).text(resizer.currentMode)
     }
 }
 
