@@ -455,7 +455,7 @@ class EventListingView(FolderListing):
         
         return final_res
         
-    def resultsFuture(self , only_documented=False):
+    def resultsFuture(self , only_documented=False, limit=None):
         """
         returns a result list for events that: today < start; Chronological order
         """
@@ -474,7 +474,10 @@ class EventListingView(FolderListing):
         #NOTE: No need to sort here since the collection is already ordered that way but it might be mor powerfull to sort anyway... for now leaving it like this for performance sake
         #final_res = sorted(res_list, key=lambda x: getattr(x, "start", False))
         
-        return res_list
+        if limit is None:
+            return res_list
+        else:
+             return res_list[:limit]
     
     def getNoEventMessage(self):
         registry = getUtility(IRegistry)
